<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs">
<context>
    <name>IsometricGridRight</name>
    <message>
        <location filename="../IsometricGridRight.js" line="+35"/>
        <source>&amp;Right Projection</source>
        <translation>&amp;Pravé promítání</translation>
    </message>
</context>
</TS>
